@@ -3,14 +3,14 @@ cat >htmlconv.spec <<EOD
 name: htmlconv
 Release: 0
 Version: $VERSION
-Copyright: OHASHI Hideya <ohac@bd.mbn.or.jp>
+Copyright: OHASHI Hideya <ohac@users.sourceforge.jp>
 Group: Utilities
 BuildArch: noarch
 Source: htmlconv-src-$VERSION.tar.gz
 Summary: Convert text file to HTML Document.
-Packager: OHASHI Hideya <ohac@bd.mbn.or.jp>
-Distribution: RedHat Linux 7.1
-BuildRoot: /home/ohac/rpm/ROOT
+Packager: OHASHI Hideya <ohac@users.sourceforge.jp>
+Distribution: Vine Linux 2.5
+BuildRoot: $RPMHOME/ROOT
 
 %description
 Convert text file to HTML Document.
@@ -27,7 +27,7 @@ mkdir -p \$RPM_BUILD_ROOT/usr/share/gnome/apps/Utilities
 %setup
 
 %build
-bash make.sh
+make all
 gzip <htmlconv.1 >htmlconv.1.gz
 
 %install
